ceiling_dec: Round numbers up to a given number of decimal places

View source: R/kija_covariate_balance.R

ceiling_decR Documentation

Round numbers up to a given number of decimal places

Description

Round numbers up to a given number of decimal places

Usage

ceiling_dec(x, digits = 1)

Arguments

x

a numeric vector

digits

integer indicating the number of decimal places

Value

The rounded up numeric vector


EpiForsk documentation built on March 30, 2026, 5:08 p.m.