ci_fct_error_handler: Handle errors returned by ci_fct

View source: R/kija_fct_confint.R

ci_fct_error_handlerR Documentation

Handle errors returned by ci_fct

Description

Handle errors returned by ci_fct

Usage

ci_fct_error_handler(e, which_parm, env)

Arguments

e

error returned by ci_fct

which_parm

Either a logical vector the same length as the coefficient vector, with TRUE indicating a coefficient is used by f, or an integer vector with the indices of the coefficients used by f.

env

environment to assign n_grid and k

Value

returns NULL if no stop command is executed.

Examples

1+1

EpiForsk documentation built on March 30, 2026, 5:08 p.m.