floor_dec: Round numbers down to a given number of decimal places

View source: R/kija_covariate_balance.R

floor_decR Documentation

Round numbers down to a given number of decimal places

Description

Round numbers down to a given number of decimal places

Usage

floor_dec(x, digits = 1)

Arguments

x

a numeric vector

digits

integer indicating the number of decimal places

Value

The rounded down numeric vector


EpiForsk documentation built on March 30, 2026, 5:08 p.m.