View source: R/adls_try_catch_warnings.R
| try_catch_warnings | R Documentation |
Try Catch with Warning Handling
try_catch_warnings(expr, character = FALSE)
expr |
An expression to be evaluated. |
character |
A logical indicating if the returned error and warning
should be characters ( |
The try_catch_warnings() funciton returns a list with three elements
values is the evaluated expr or NULL if the evaluations throws an
error.
warning is any warning given while evaluating expr. When character =
FALSE, the default, warning is a simpleWarning, otherwise
it is a character.
error is any error given while trying to evaluate expr. When
character = FALSE, the default, error is a simpleError,
otherwise it is a character.
# No errors or warnings
try_catch_warnings(log(2))
# Warnings
try_catch_warnings(log(-1))
# Errors
try_catch_warnings(stop("Error Message"))
try_catch_warnings(stop("Error Message"), character = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.